;Each cdf file (Vsvy, FBK, Spec, spinfit) will return the exact same flag
;structure ("efw_qual"). The difficulty is that the different crib sheets will
;need to communicate somehow. We've decided that each crib sheet will produce
;the "efw_qual" tag in the cdf. The skeleton will initiate this qual cdf
;with "dunno" values. After all the crib sheets have been run for a day
;they will pool together their flag cdfs and a separate program will combine
;them into a master version. 


;The flag array to be inserted into CDF has the following 20 fields:
	;global_flag
	;eclipse
	;maneuver
	;efw_sweep
	;efw_deploy
	;v1_saturation
	;v2_saturation
	;v3_saturation
	;v4_saturation
	;v5_saturation
	;v6_saturation
	;Espb_magnitude
	;Eparallel_magnitude
	;magnetic_wake
	;undefined	
	;undefined	
	;undefined	
	;undefined	
	;undefined	
	;undefined	



;Vsvy data to cdf file

;Test program to put the vsvy values into the CDF skeleton. 

;Issues:
;	Need to write a CDF reader program to apply the correct labels to the flag values


;Written by Aaron W Breneman  03/2013

;31 Oct 2012	IP Shock and Pulsations (Large and Small Amplitude Signals)
;01 Nov 2012	Big Storm
;14 Nov 2012	Plasma Sheet Boundary layer Crossings
;13 Feb 2013	Dipolarizations
;17 Feb 2013	Dipolarizations


pro rbsp_efw_make_l2_vsvy,sc,date,folder=folder


	if ~keyword_set(folder) then folder ='~/Desktop/code/Aaron/RBSP/l2_processing_cribs/'
	source_file = 'rbspx_vsvy_l2_00000000_v01.cdf'



	filematch = file_search(folder+source_file, count = filecount) ;check for existence of output file


;Load some data
	timespan,date
	rbspx = 'rbsp'+sc

	version = 'v01'

;Rename the skeleton file 
	filename = 'rbsp'+sc+'_vsvy_l2_'+strjoin(strsplit(date,'-',/extract))+'_'+version+'.cdf'
	file_copy,folder+source_file,folder+filename


;Load the survey data
	rbsp_load_efw_waveform,probe=sc,type='calibrated',datatype='vsvy'
	get_data,rbspx+'_efw_vsvy',data=vsvy 


;Not ready to release the V5, V6 values.
	vsvy.y[*,4] = -1.0e30
	vsvy.y[*,5] = -1.0e30


;Get the time structure for the flag values
	epoch_flag_times,date,5,epochvals,timevals



;Load HSK data
	rbsp_load_efw_hsk,probe=sc,/get_support_data

	get_data,rbspx+'_efw_vsvy_ccsds_data_BEB_config',data=beb
	get_data,rbspx+'_efw_vsvy_ccsds_data_DFB_config',data=dfb




;Get flag values

	fill_val = -1  ;value in flag array that indicates "dunno"
	maxvolts = 180. ;Max antenna voltage above which the saturation flag is thrown
	offset = 5   ;position in flag_arr of "v1_saturation" 

	tmp = replicate(0,n_elements(vsvy.x),6)
	flag_arr = replicate(fill_val,n_elements(timevals),20)


	for i=0,5 do begin

		;Change bad values to "1"
		vbad = where(abs(vsvy.y[*,i]) ge maxvolts)
		if vbad[0] ne -1 then tmp[vbad,i] = 1

		;Change good values to "0"
		vgood = where(abs(vsvy.y[*,i]) lt maxvolts)
		if vgood[0] ne -1 then tmp[vgood,i] = 0

		;Interpolate the bad data values onto the pre-defined flag value times
		flag_arr[*,i+offset] = ceil(interpol(tmp[*,i],vsvy.x,timevals))

	endfor



;Create average values of opposing antennas
	v1v2 = 0.5*(vsvy.y[*,0] + vsvy.y[*,1])
	v3v4 = 0.5*(vsvy.y[*,2] + vsvy.y[*,3])
	v5v6 = 0.5*(vsvy.y[*,4] + vsvy.y[*,5])

	v5v6[*] = -1.0e30
	
	
	vsvy_vavg = [[v1v2],[v3v4],[v5v6]]



;Make the time string
	times = vsvy.x
	times_hsk = beb.x

	epoch = tplot_time_to_epoch(times,/epoch16)
	epoch_hsk = tplot_time_to_epoch(times_hsk,/epoch16)




 
;Stuff values into the cdf skeleton structure

	cdfid = cdf_open(folder+filename)
	cdf_control, cdfid, get_var_info=info, variable='epoch'


	cdf_varput,cdfid,'epoch',epoch
	cdf_varput,cdfid,'epoch_hsk',epoch_hsk
	cdf_varput,cdfid,'epoch_qual',epochvals
	cdf_varput,cdfid,'vsvy',transpose(vsvy.y)
	cdf_varput,cdfid,'vsvy_vavg',transpose(vsvy_vavg)
	cdf_varput,cdfid,'vsvy_DFB_config',dfb.y
	cdf_varput,cdfid,'vsvy_BEB_config',beb.y
	cdf_varput,cdfid,'efw_qual',transpose(flag_arr)


	cdf_close, cdfid



	store_data,tnames(),/delete




;Load the newly filled CDF structure to see if it works

	cdf_leap_second_init
	cdf2tplot,files=folder + filename

	ylim,'vsvy',-20,20
	ylim,'vsvy_vavg',-20,20
	ylim,'vsvy_DFB_config',-2,2
	ylim,'vsvy_BEB_config',-2,2

	names = ['global_flag',$
		'eclipse',$
		'maneuver',$
		'efw_sweep',$
		'efw_deploy',$
		'v1_saturation',$
		'v2_saturation',$
		'v3_saturation',$
		'v4_saturation',$
		'v5_saturation',$
		'v6_saturation',$
		'Espb_magnitude',$
		'Eparallel_magnitude',$
		'magnetic_wake',$
		'undefined	',$
		'undefined	',$
		'undefined	',$
		'undefined	',$
		'undefined',$
		'undefined']

	split_vec,'efw_qual',suffix='_'+names

	tplot,['vsvy','vsvy_vavg','vsvy_DFB_config','vsvy_BEB_config','efw_qual']




end